unit ProfilesForm_Unit;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls;

type
  TProfilesForm = class(TForm)
    Panel1: TPanel;
    Label1: TLabel;
    ProfilesListBox: TListBox;
    ProfilesEdit: TEdit;
    CreateButton: TButton;
    DeleteButton: TButton;
    LoadButton: TButton;
    CancelButton: TButton;
    procedure FormShow(Sender: TObject);
    procedure ProfilesEditChange(Sender: TObject);
    procedure CreateButtonClick(Sender: TObject);
    procedure DeleteButtonClick(Sender: TObject);
    procedure ProfilesListBoxClick(Sender: TObject);
    procedure ProfilesListBoxDblClick(Sender: TObject);
    procedure LoadButtonClick(Sender: TObject);
    procedure ProfilesEditKeyPress(Sender: TObject; var Key: Char);
    procedure CancelButtonClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

Procedure UpdateProfiles;

var
  ProfilesForm: TProfilesForm;

implementation

uses MainForm_Unit;

{$R *.dfm}

procedure TProfilesForm.FormShow(Sender: TObject);
begin
  UpdateProfiles;
end;

Procedure UpdateProfiles;
var ProfilesFile : File of Profile;
    ProfilesIndex : Profile;
    ProfilesPath : String;
begin
  ProfilesPath := GetCurrentDir + '\PROFILES\';
  with ProfilesForm do
  begin
    ProfilesListBox.Clear;
    ProfilesEdit.Clear;
    if not DirectoryExists(ProfilesPath) then
      CreateDir(ProfilesPath);
    if FileExists(ProfilesPath + 'profiles.dat') then
    begin
      ProfilesListBox.Enabled := TRUE;
      AssignFile(ProfilesFile, ProfilesPath + 'profiles.dat');
      Reset(ProfilesFile);
      while not EoF(ProfilesFile) do
      begin
        Read(ProfilesFile, ProfilesIndex);
        ProfilesListBox.Items.Add(ProfilesIndex.Name);
      end;
      CloseFile(ProfilesFile);
    end else
    begin
      ProfilesListBox.Enabled := FALSE;
      ProfilesListBox.Items.Add('none');
    end;
  end;
end;

procedure TProfilesForm.ProfilesEditChange(Sender: TObject);
begin
  if ProfilesEdit.Text = '' then
  begin
    CreateButton.Enabled := FALSE;
    DeleteButton.Enabled := FALSE;
    LoadButton.Enabled := FALSE;
  end else
  begin
    CreateButton.Enabled := TRUE;
    DeleteButton.Enabled := TRUE;
    LoadButton.Enabled := TRUE;
  end;
end;

procedure TProfilesForm.CreateButtonClick(Sender: TObject);
var ProfilesFile : File of Profile;
    ProfilesIndex : Profile;
    ProfilesPath : String;
begin
  ProfilesPath := GetCurrentDir + '\PROFILES\';
  AssignFile(ProfilesFile, ProfilesPath + 'profiles.dat');
  if FileExists(ProfilesPath + 'profiles.dat') then
    Reset(ProfilesFile)
  else ReWrite(ProfilesFile);
  while not EoF(ProfilesFile) do
  begin
    Read(ProfilesFile, ProfilesIndex);
    if AnsiLowerCase(ProfilesIndex.Name) = AnsiLowerCase(ProfilesEdit.Text) then
    if MessageBox(0, 'Profile already exists. Overwrite?', 'Question', MB_YESNO or MB_ICONQUESTION) = IDYES then
    begin
      Seek(ProfilesFile, FilePos(ProfilesFile)-1);
      Break;
    end else
    begin
      CloseFile(ProfilesFile);
      Exit;
    end;
  end;
  ProfilesIndex.Name := ProfilesEdit.Text;
  ProfilesIndex.IRCServer := '';
  ProfilesIndex.IRCPort := 6667;
  ProfilesIndex.BotNick := '';
  ProfilesIndex.Channel := '';
  Write(ProfilesFile, ProfilesIndex);
  CloseFile(ProfilesFile);
  MainProfile := ProfilesIndex;
  MainForm.StatusBar.Panels[1].Text := 'Profile: ' + ProfilesIndex.Name;
  ProfilesForm.Close;
end;

procedure TProfilesForm.DeleteButtonClick(Sender: TObject);
var ProfilesFile : File of Profile;
    ProfilesIndex : Profile;
    ProfilesPath : String;
    Pos : Integer;
begin
  ProfilesPath := GetCurrentDir + '\PROFILES\';
  AssignFile(ProfilesFile, ProfilesPath + 'profiles.dat');
  if FileExists(ProfilesPath + 'profiles.dat') then
  begin
    Reset(ProfilesFile);
    while not EoF(ProfilesFile) do
    begin
      Read(ProfilesFile, ProfilesIndex);
      if AnsiLowerCase(ProfilesIndex.Name) = AnsiLowerCase(ProfilesEdit.Text) then
      begin
        if FileSize(ProfilesFile) = 1 then
        begin
          CloseFile(ProfilesFile);
          DeleteFile(ProfilesPath + 'profiles.dat');
          UpdateProfiles;
          Exit;
        end else
        begin
          Pos := FilePos(ProfilesFile)-1;
          Seek(ProfilesFile, FileSize(ProfilesFile)-1);
          Read(ProfilesFile, ProfilesIndex);
          Seek(ProfilesFile, Pos);
          Write(ProfilesFile, ProfilesIndex);
          Seek(ProfilesFile, FileSize(ProfilesFile)-1);
          TrunCate(ProfilesFile);
          CloseFile(ProfilesFile);
          UpdateProfiles;
          Exit;
        end;
      end;
    end;
  end;
  CloseFile(ProfilesFile);
  MessageBox(0, 'Profile does not exists.', 'Error', MB_OK or MB_ICONERROR);
end;

procedure TProfilesForm.ProfilesListBoxClick(Sender: TObject);
begin
  ProfilesEdit.Text := ProfilesListBox.Items[ProfilesListBox.ItemIndex];
end;

procedure TProfilesForm.ProfilesListBoxDblClick(Sender: TObject);
begin
  LoadButton.Click;
end;

procedure TProfilesForm.LoadButtonClick(Sender: TObject);
var ProfilesFile : File of Profile;
    ProfilesIndex : Profile;
    ProfilesPath : String;
begin
  ProfilesPath := GetCurrentDir + '\PROFILES\';
  AssignFile(ProfilesFile, ProfilesPath + 'profiles.dat');
  if FileExists(ProfilesPath + 'profiles.dat') then
  begin
    Reset(ProfilesFile);
    while not EoF(ProfilesFile) do
    begin
      Read(ProfilesFile, ProfilesIndex);
      if AnsiLowerCase(ProfilesIndex.Name) = AnsiLowerCase(ProfilesEdit.Text) then
      begin
        MainProfile := ProfilesIndex;
        MainForm.StatusBar.Panels[1].Text := 'Profile: ' + ProfilesIndex.Name;
        CloseFile(ProfilesFile);
        ProfilesForm.Close;
        Exit;
      end;
    end;
    CloseFile(ProfilesFile);
  end;
  MessageBox(0, 'Profile not found.', 'ERROR', MB_OK or MB_ICONERROR);
end;

procedure TProfilesForm.ProfilesEditKeyPress(Sender: TObject;
  var Key: Char);
begin
  if Key = #13 then CreateButton.Click;
end;

procedure TProfilesForm.CancelButtonClick(Sender: TObject);
begin
  Close;
end;

procedure TProfilesForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  with MainForm do
  begin
    if StatusBar.Panels[1].Text = 'Profile: [none]' then
    begin
      Options1.Enabled := FALSE;
      OnlineButton.Enabled := FALSE;
    end else
    begin
      Options1.Enabled := TRUE;
      OnlineButton.Enabled := TRUE;
    end;
  end;
end;

end.
